==> dl.php?src=linea21_1_6.zip: linea21/languages/fr/lang_project.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "projets";

/*	nommage des modules
 *  	*/
$lang['project']['name']="projet";
$lang['project']['confirm_add'] = "Ajout du projet réalisé avec succès\n";
$lang['project']['confirm_mod'] = "Modification du projet réalisée avec succès\n";
$lang['project']['confirm_sup'] ="Suppression du projet réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Ajout d'un ".$lang['project']['name'];
$lang['project']['mod']= "Modification du ".$lang['project']['name'];
$lang['project']['sup']= "Suppression du ".$lang['project']['name'];
$lang['project']['det']= "Détails du ".$lang['project']['name'];
$lang['project']['list']= "Consultation des projets";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']="Saisie des informations du nouveau ".$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nom du ".$lang['project']['name'];
$lang['project']['description']="description";
$lang['project']['body']="contenu";
$lang['project']['begin_date']="début du projet";
$lang['project']['estimated_date']="fin estimée";
$lang['project']['end_date']="fin effective";
$lang['project']['progression']="progression (en %)";
$lang['project']['parent']="projet parent";
$lang['project']['sub-projects']="Sous projets";
$lang['project']['priority']="priorité ";
$lang['project']['theme']="thème ";
$lang['project']['workshop']="groupe de travail ";
$lang['project']['sdi']="indicateurs ";
$lang['project']['scale']="échelle ";
$lang['project']['author']="auteur ";
$lang['project']['statut']='état de publication';

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" derniers ajouts effectués";
$lang['project']['qb_titlemod']=" dernières modifications effectuées";
$lang['project']['qb_titlesup']=" dernières suppressions effectuées";
$lang['project']['qb_titlepubli']=' dernières publications effectuées';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Faites votre choix dans la liste ci dessous --";

$lang['project']['nb_total']='projets sont stockés dans la base de données.';
$lang['project']['statut_filter']='Afficher par statut';
$lang['project']['all']='Afficher la liste complete';
$lang['project']['noresult']='Aucun projet ne correspond à ce critère de sélection ';

/*	messages
 *  	*/
$lang['project']['no_name']="Vous devez impérativement entrer un nom à votre projet";
$lang['project']['no_description']="Votre projet doit impérativement avoir une description";
$lang['project']['no_body']="Votre projet doit impérativement avoir un contenu";
$lang['project']['no_scale']='Votre projet doit impérativement être associé à une échelle';
$lang['project']['no_priority']='Votre projet doit impérativement être associé à une priorité';
$lang['project']['progression_error']='L\'indicateur de progression doit prendre une valeur entre 0 et 100.';
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Pour ajouter un projet, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['project']['help_add2']="Après avoir validé le formulaire d'ajout, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_add3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['project']['help_list1']="Pour afficher un projet en détail, cliquez sur le nom de celui-ci";
$lang['project']['help_list2']="Vous pouvez supprimer un projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_list3']="Vous pouvez modifier un projet en cliquant sur l'icône de modification qui lui est associée";
$lang['project']['help_list4']="Pour ajouter un projet, cliquez sur le lien 'ajouter un projet' dans la barre de titre";
$lang['project']['help_list5']="Vous pouvez faire une recherche de projet à tout moment en cliquant sur 'recherche'";

$lang['project']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['project']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";

$lang['project']['help_det1']="Pour afficher le projet parent du projet détaillé, cliquez sur le nom de celui-ci";
$lang['project']['help_det2']="Vous pouvez supprimer ce projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_det3']="Vous pouvez modifier ce projet en cliquant sur l'icône de modification qui lui est associée";

$lang['project']['help_sup1']="Attention, si ce projet contient des sous projets ils ne seront pas automatiquement effacés";
?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/fr/lang_project.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "projets";

/*	nommage des modules
 *  	*/
$lang['project']['name']="projet";
$lang['project']['confirm_add'] = "Ajout du projet réalisé avec succès\n";
$lang['project']['confirm_mod'] = "Modification du projet réalisée avec succès\n";
$lang['project']['confirm_sup'] ="Suppression du projet réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Ajout d'un ".$lang['project']['name'];
$lang['project']['mod']= "Modification du ".$lang['project']['name'];
$lang['project']['sup']= "Suppression du ".$lang['project']['name'];
$lang['project']['det']= "Détails du ".$lang['project']['name'];
$lang['project']['list']= "Consultation des projets";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']="Saisie des informations du nouveau ".$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nom du ".$lang['project']['name'];
$lang['project']['description']="description";
$lang['project']['body']="contenu";
$lang['project']['budget']="budget (en €)";
$lang['project']['coordinator']="coordinateur";
$lang['project']['partners']="partenaires";
$lang['project']['begin_date']="début du projet";
$lang['project']['estimated_date']="fin estimée";
$lang['project']['end_date']="fin effective";
$lang['project']['progression']="progression (en %)";
$lang['project']['parent']="projet parent";
$lang['project']['sub-projects']="Sous projets";
$lang['project']['priority']="priorité ";
$lang['project']['theme']="thème ";
$lang['project']['workshop']="groupe de travail ";
$lang['project']['sdi']="indicateurs ";
$lang['project']['scale']="échelle ";
$lang['project']['author']="auteur ";
$lang['project']['statut']='état de publication';

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" derniers ajouts effectués";
$lang['project']['qb_titlemod']=" dernières modifications effectuées";
$lang['project']['qb_titlesup']=" dernières suppressions effectuées";
$lang['project']['qb_titlepubli']=' dernières publications effectuées';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Faites votre choix dans la liste ci dessous --";

$lang['project']['nb_total']='projets sont stockés dans la base de données.';
$lang['project']['statut_filter']='Afficher par statut';
$lang['project']['all']='Afficher la liste complete';
$lang['project']['noresult']='Aucun projet ne correspond à ce critère de sélection ';

/*	messages
 *  	*/
$lang['project']['no_name']="Vous devez impérativement entrer un nom à votre projet";
$lang['project']['no_description']="Votre projet doit impérativement avoir une description";
$lang['project']['no_body']="Votre projet doit impérativement avoir un contenu";
$lang['project']['no_scale']='Votre projet doit impérativement être associé à une échelle';
$lang['project']['no_priority']='Votre projet doit impérativement être associé à une priorité';
$lang['project']['progression_error']='L\'indicateur de progression doit prendre une valeur entre 0 et 100.';
$lang['project']['budget_integer']='Budget : un chiffre entier doit être entré';
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Pour ajouter un projet, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['project']['help_add2']="Après avoir validé le formulaire d'ajout, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_add3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['project']['help_list1']="Pour afficher un projet en détail, cliquez sur le nom de celui-ci";
$lang['project']['help_list2']="Vous pouvez supprimer un projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_list3']="Vous pouvez modifier un projet en cliquant sur l'icône de modification qui lui est associée";
$lang['project']['help_list4']="Pour ajouter un projet, cliquez sur le lien 'ajouter un projet' dans la barre de titre";
$lang['project']['help_list5']="Vous pouvez faire une recherche de projet à tout moment en cliquant sur 'recherche'";

$lang['project']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['project']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";

$lang['project']['help_det1']="Pour afficher le projet parent du projet détaillé, cliquez sur le nom de celui-ci";
$lang['project']['help_det2']="Vous pouvez supprimer ce projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_det3']="Vous pouvez modifier ce projet en cliquant sur l'icône de modification qui lui est associée";

$lang['project']['help_sup1']="Attention, si ce projet contient des sous projets ils ne seront pas automatiquement effacés";
?>
